#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of carman-python.
#
#  carman-python is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  carman-python is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import re
from maps.manageaccountdlgview import ManageAccountDlgView
from main.messagedlgctrl import MessageDlgController
from models.kbmodel import KeyBoardModel


def message_error(title, message, cb):
    msg_error = MessageDlgController(cb)
    msg_error.show_message(message, title=title)


class CommonAccountController(object):

    def __init__(self, title, info, save_cb):
        self.__title = title
        self.__info = info
        self.__edited_info = {}
        self.protocol_id = self.__info['protocol_id']
        if 'username' not in self.__info:
            self.__edited_info = self.__info
            self.__info = {}
        self.__save_cb = callable(save_cb) and save_cb or None
        self.selected_protocol = None

    def __basic_info_page(self, check_account_exist):
        self.basic_info = BasicInfoController(self.__title,
                self.protocol_id, self.__password_info_page,
                self.__return_to_protocol, check_account_exist)
        self.basic_info.show()
        self.__set_basic_info()

    def __password_info_page(self, *p):
        self.set_specific_server()
        self.password_info = PasswordInfoController(self.__title,
                self.__server_info_page, self.__return_to_basic)
        self.password_info.show()
        self.__set_password_info()

    def __server_info_page(self, *p):
        self.server_info = ServerInfoController(self.__title,
                self.__save_info, self.__return_to_password)
        self.server_info.show()
        self.__set_server_info()

    def __return_to_protocol(self):
        KeyBoardModel().set_focus()
        self.__get_basic_info()

    def __return_to_basic(self):
        self.basic_info.view.first_entry_focus()
        self.__get_password_info()

    def __return_to_password(self):
        self.password_info.view.first_entry_focus()
        self.__get_server_info()

    def __set_basic_info(self):
        view = self.basic_info.view
        view.first_entry.text = self.get_dict_value('username').split("/")[0]
        view.second_entry.text = self.get_dict_value('alias')

    def __set_password_info(self):
        view = self.password_info.view
        view.first_entry.text = self.get_dict_value('password')
        view.remember = self.get_dict_value('remember_password')
        if not view.remember:
            view.remember = 0
        else:
            view.signal_emit("enable-remember", "")

    def __set_server_info(self):
        view = self.server_info.view
        view.first_entry.text = self.get_dict_value('server')
        view.second_entry.text = str(self.get_dict_value('port'))

    def __get_basic_info(self):
        view = self.basic_info.view
        self.set_dict_value('username', view.first_entry.text.strip())
        self.set_dict_value('alias', view.second_entry.text.strip())

    def __get_password_info(self):
        view = self.password_info.view
        self.set_dict_value('password', view.first_entry.text.strip())
        self.set_dict_value('remember_password', view.remember)

    def __get_server_info(self):
        view = self.server_info.view
        self.set_dict_value('server', view.first_entry.text.strip())
        self.set_dict_value('port', view.second_entry.text.strip())

    def __save_info(self, *p):
        self.__get_basic_info()
        self.__get_password_info()
        self.__get_server_info()
        self.server_info.hide()
        self.password_info.hide()
        self.basic_info.hide()
        KeyBoardModel().set_focus()

        # Hack to avoid resource problems
        if self.get_dict_value('protocol_id') == 'prpl-jabber':
            self.set_dict_value('username', \
                self.get_dict_value('username').split("/")[0] + "/Carman")

        self.__save_cb(self.__edited_info)
        self.__save_cb = None

    def show(self, check_account_exist):
        self.__basic_info_page(check_account_exist)

    def set_specific_server(self):
        domain = self.basic_info.view.first_entry.text.split("@")
        if self.get_dict_value('protocol_id') == 'prpl-jabber' and \
                'server' in self.__edited_info and len(domain) > 1 and \
                domain[1] == "gmail.com":
            self.__edited_info['server'] = "talk.google.com"

    def get_dict_value(self, key):
        if key in self.__edited_info:
            return self.__edited_info[key]
        elif key in self.__info and self.__info[key]:
            return self.__info[key]
        else:
            return ""

    def set_dict_value(self, key, value):
        if key in self.__info and self.__info[key] == value and \
                key in self.__edited_info:
            del self.__edited_info[key]
        elif (key in self.__info and self.__info[key] != value) or \
                key not in self.__info:
            self.__edited_info[key] = value


class BasicInfoController(object):

    def __init__(self, title, protocol, cb, r_cb, check_account_exist):
        self.__title = title
        self.__protocol = protocol
        self.cb = callable(cb) and cb or None
        self.r_cb = callable(r_cb) and r_cb or None
        self.__check_account_exist = check_account_exist

    def show(self):
        self.view = ManageAccountDlgView(self.__title, self.__confirm_cb,
                self.__return, "manageaccountdlg1")
        self.view.show()

    def __confirm_cb(self, *p):
        if self.check_username():
            self.cb()
            return True
        return False

    def __return(self, *p):
        self.r_cb()
        self.cb = self.r_cb = None

    def check_username(self):
        username = self.view.first_entry.text.strip()
        if username == "":
            message_error(self.__title, "Login cannot be empty.",
                    self.view.first_entry_focus)
            return False
        return True

    def hide(self):
        self.cb = self.r_cb = None
        self.view.hide(True)


class PasswordInfoController(object):

    def __init__(self, title, cb, r_cb):
        self.__title = title
        self.cb = callable(cb) and cb or None
        self.r_cb = callable(r_cb) and r_cb or None

    def show(self):
        self.view = ManageAccountDlgView(self.__title, self.__confirm_cb,
                self.__return, "manageaccountdlg2")
        self.view.show()

    def __confirm_cb(self, *p):
        self.cb()

    def __return(self, *p):
        self.r_cb()
        self.cb = self.r_cb = None

    def hide(self):
        self.cb = self.r_cb = None
        self.view.hide(True)


class ServerInfoController(object):

    def __init__(self, title, cb, r_cb):
        self.__title = title
        self.cb = callable(cb) and cb or None
        self.r_cb = callable(r_cb) and r_cb or None

    def show(self):
        self.view = ManageAccountDlgView(self.__title, self.__confirm_cb,
                self.__return,
                "manageaccountdlg1")
        self.view.part_text_set("label", "Server")
        self.view.part_text_set("label2", "Port")
        self.view.part_text_set("cancel_bt_label", "Back")
        self.view.part_text_set("confirm_bt_label", "Save")
        self.view.show()

    def __confirm_cb(self, *p):
        if self.check_server() and self.check_port():
            self.cb()
            return False
        return True

    def __return(self, *p):
        self.r_cb()
        self.cb = self.r_cb = None

    def check_server(self):
        if self.view.first_entry.text.strip()  == "":
            message_error(self.__title, "Server cannot be empty.",
                    self.view.first_entry_focus)
            self.view.first_entry.text = ""
            return False
        return True

    def check_port(self):
        if not re.match("[0-9]*$", self.view.second_entry.text) or \
                self.view.second_entry.text.strip() == "":
            message_error(self.__title, \
                "Port field can only contain numbers.", \
                self.view.second_entry_focus)
            self.view.second_entry.text = ""
            return False
        return True

    def hide(self):
        self.cb = self.r_cb = None
        self.view.hide(True)
