#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of carman-python.
#
#  carman-python is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  carman-python is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from common.carlog import DEBUG
from main.listctrl import ListView
from main.messagedlgctrl import MessageDlgController
from models.buddymodel import BuddyModel
from models.infosharingmodel import InfoSharingModel

class DisconnectBuddyController(object):

    def __init__(self, parent):
        self._parent = parent
        self.buddy_model = BuddyModel()
        self.is_model = InfoSharingModel()
        self.view = ListView("list-normal", "list-item-normal", \
            "DISCONNECT BUDDY")

    def __del__(self):
        DEBUG("deleting DisconnectBuddyController %s" % self)

    def __buddy_selected_cb(self, obj, item, param):
        def disconnect_buddy():
            self.buddy_model.disconnect_buddy(param)

        obj.hide(True)
        self._parent.hide(True)
        msg = MessageDlgController(confirm_cb=disconnect_buddy)
        msg.show_message("Do you want to disconnect from<br>%s?" % param, \
                buttons=2, title="DISCONNECT_BUDDY")

    def load_list(self):
        for buddy in self.buddy_model.get_connected_buddies():
            alias = self.is_model.get_buddy_alias(buddy)
            if alias:
                self.view.add_item(alias, self.__buddy_selected_cb, buddy)
            else:
                self.view.add_item(buddy, self.__buddy_selected_cb, buddy)

        if self.view.has_items():
            return True
        else:
            self.view.hide(True)
            msg = MessageDlgController()
            msg.show_message("No buddies left to disconnect", \
                    title="DISCONNECT BUDDY")
            return False

    def show(self):
        self.view.show()
