#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of carman-python.
#
#  carman-python is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  carman-python is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import etk

from common.carlog import DEBUG
from main.mainview import MainView
from main.basedlgview import BaseDlgView

class ManageAccountDlgView(BaseDlgView):

    def __init__(self, title, cb, return_cb, group_name):
        canvas = MainView().get_evas_canvas()
        self.title = title
        self.group_name = group_name
        BaseDlgView.__init__(self, self.group_name, 30)
        self.part_text_set("title", self.title)

        self.first_entry = etk.Entry()

        if self.group_name != "manageaccountdlg2":
            self.second_entry = etk.Entry()
        self.remember_rect = None

        if self.group_name == "manageaccountdlg2":
            self.first_entry.password_mode = True
            self.remember = False
            self.signal_callback_add("remember_password_clicked", "",
                    self.__remember_selected_cb)
            self.remember_rect = self.part_object_get('remember_password')
            self.remember_rect.on_key_down_add(self.__key_down)
            self.remember_rect.on_mouse_down_add(self.__mouse_down)

        embed = etk.Embed(canvas)
        embed.add(self.first_entry)
        self.__connect_unfocused()
        self.first_entry.on_key_down(self.__key_down)
        self.first_entry.on_mouse_down(self.__mouse_down)
        embed.show_all()
        self.part_swallow("display_label", embed.object)

        if self.group_name != "manageaccountdlg2":
            embed2 = etk.Embed(canvas)
            embed2.add(self.second_entry)
            self.second_entry.on_key_down(self.__key_down)
            self.second_entry.on_mouse_down(self.__mouse_down)
            embed2.show_all()
            self.part_swallow("display_label2", embed2.object)

        self.first_entry.focus()
        self.cb = callable(cb) and cb or None
        self.cb_r = callable(return_cb) and return_cb or None
        self.signal_callback_add("hide", "", self.__destroy)
        self.signal_callback_add("confirm_bt_clicked", "", self.__confirm_cb)
        self.signal_callback_add("cancel_bt_clicked", "", self.__cancel_cb)

    def __del__(self):
        DEBUG("deleting ManageAccountView %s" % self)

    def focus_out_cb(self, obj):
        obj.focus()

    def __mouse_down(self, obj, event):
        if obj == self.first_entry:
            self.first_entry_focus()
        else:
            if self.group_name != "manageaccountdlg2":
                self.second_entry_focus()
            else:
                self.remember_focus()

    def __key_down(self, obj, event):
        if event.key == "Escape":
            self.__cancel_cb()
        elif event.key in ("Return", "KP_Enter"):
            if obj == self.first_entry:
                if self.group_name == "manageaccountdlg2":
                    self.remember_focus()
                else:
                    self.second_entry_focus()
            else:
                self.__confirm_cb()
        elif obj == self.remember_rect and event.key == "space":
            self.__remember_selected_cb()
        return True

    def __connect_unfocused(self):
        self.first_entry.on_unfocused(self.focus_out_cb)
        self.frst_focus = True

    def __disconnect_unfocused(self):
        self.first_entry.disconnect(self.first_entry.UNFOCUSED_SIGNAL,
                self.focus_out_cb)
        self.frst_focus = False

    def __confirm_cb(self, *data):
        if self.frst_focus:
            self.__disconnect_unfocused()
        if self.cb:
            self.cb(self)

    def __cancel_cb(self, *date):
        if self.cb_r:
            self.cb_r()
        self.hide(True)

    def __remember_selected_cb(self, *cb):
        if self.remember:
            self.signal_emit("disable-remember", "")
        else:
            self.signal_emit("enable-remember", "")
        self.remember = not self.remember

    def __destroy(self, *data):
        self.cb = self.cb_r = None
        if self.frst_focus:
            self.__disconnect_unfocused()
        self.first_entry.destroy()
        if self.group_name != "manageaccountdlg2":
            self.second_entry.destroy()

    def first_entry_focus(self):
        if not self.frst_focus:
            self.__connect_unfocused()
            self.frst_focus = True
        if self.group_name != "manageaccountdlg2":
            self.second_entry.unfocus()
        if self.remember_rect:
            self.remember_rect.focus_set(False)
        self.first_entry.focus()

    def second_entry_focus(self):
        if self.frst_focus:
            self.__disconnect_unfocused()
        self.first_entry.unfocus()
        if self.remember_rect:
            self.remember_rect.focus_set(False)
        self.second_entry.focus()

    def remember_focus(self):
        if self.frst_focus:
            self.__disconnect_unfocused()
        self.first_entry.unfocus()
        self.remember_rect.focus_set(True)
