#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of carman-python.
#
#  carman-python is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  carman-python is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

class InfoSharingService(object):
    """
    InfoSharing service interface
    """

    def __init__(self):
        pass

    def send_message(self, name, message):
        """
        Sends a message to a specified buddy.

        @param name    Buddy name (e-mail)
        @param message Buddy message
        """
        pass

    def remove_account(self):
        """
        Remove an account

        @param acc_id (username, protocol_id)
        """
        pass

    def set_account_info(self, info):
        """
        Set account information

        @param info   Tuple of informations. e.g:
                      { username, protocol_id, password, alias,
                        remember_password, server, port }
        """
        pass

    def get_account_info(self):
        """
        Get account information

        @return info  Tuple of informations. e.g:
                      { username, protocol_id, password, alias,
                        remember_password, server, port }
        """
        pass

    def get_account(self):
        """
        Get current infoshare account
        """
        pass

    def account_connect(self):
        """
        Connect account

        """
        pass

    def account_disconnect(self):
        """
        Disconnect account

        @param acc_id (username, protocol_id)
        """
        pass

    def account_is_enabled(self):
        """
        Verify if account is enabled

        """
        pass

    def account_is_connected(self):
        """
        Verify if account is connected

        """
        pass

    def account_is_connecting(self):
        """
        Verify if account is connecting

        """
        pass

    def account_is_disconnected(self):
        """
        Verify if account is disconnected

        """
        pass

    def account_exists(self):
        """
        Verify if account exists

        """
        pass

    def set_account_password(self, password=None, remember=None):
        """
        Set account password

        @param password Account password
        @param remember Check if account's password will be remembered
        """
        pass

    def get_account_password(self):
        """
        Get account password

        """
        pass

    def get_protocol_options(self, protocol_id):
        """
        Get a dictionary of protocol options

        @param protocol_id Protocol's ID for retrieve options
        @return Dictionary of protocol options
        """
        pass

    def get_protocols(self):
        """
        Get needed protocols list
        """
        pass

    def add_buddy(self, name, alias=None, group=None):
        """
        Adds a buddy into a following account

        @param name   Buddy name
        @param alias  Buddy alias (optional)
        @param group  Buddy group (optional)
        """
        pass

    def buddy_exists(self, name):
        """
        Verify if a buddy exists into a given account

        @param name   Buddy name
        """
        pass

    def remove_buddy(self, name):
        """
        Removes a buddy from an account

        @param name   Buddy name
        """
        pass

    def get_buddies_online(self):
        """
        Get a list of online buddies using Carman

        """
        pass

    def get_buddies(self):
        """
        Get a list of all buddies

        """
        pass

    def get_buddy_presence(self, name):
        """
        Get buddy presence

        @param name   Buddy name
        """
        pass

    def get_buddy_alias(self, name):
        """
        Get buddy alias

        @param name   Buddy name
        """
        pass

    def set_buddy_alias(self, name, alias):
        """
        Set buddy alias

        @param name   Buddy name
        @param alias  Buddy alias
        """
        pass
