#
#  Copyright (c) 2008 INdT - Instituto Nokia de Tecnologia
#
#  This file is part of carman-python.
#
#  carman-python is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  carman-python is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from common.carlog import DEBUG
from main.messagedlgctrl import MessageDlgController
from maps.managenewbuddyview import ManageNewBuddyDlgView
from models.infosharingmodel import InfoSharingModel

class NewBuddyController(object):

    def __init__(self, parent):
        self.is_service = InfoSharingModel().service
        self.view = ManageNewBuddyDlgView(self.__save_buddy_cb)

    def __del__(self):
        DEBUG("deleting NewBuddyController %s" % self)

    def __get_account_active(self):
        ''' In Carman we have only an active account '''
        accounts = self.is_service.get_accounts_active()
        if not accounts:
            return None
        else:
            return accounts[0]

    def __buddy_exists(self, email, account):
        # FIXME: Buddies online is just a hack to know the buddy was
        # added and it accepted my request, else I can add it again.
        buddies = self.is_service.get_buddies_online()
        for buddy in buddies:
            if email == buddy[0]:
                return True
        return False

    def __save_buddy_cb(self):
        email = self.view.name_entry.text.strip()
        account = self.__get_account_active()
        if not account:
            msg = MessageDlgController()
            msg.show_message("No accounts active", title="NEW BUDDY")
            obj.hide(True)
            return
        elif  email == "":
            msg = MessageDlgController(self.view.name_entry_focus)
            msg.show_message("E-mail cannot be empty", title="NEW BUDDY")
            return
        elif self.__buddy_exists(email, account):
            msg = MessageDlgController(self.view.name_entry_focus)
            msg.show_message("Buddy already exists", title="NEW BUDDY")
            return
        elif email == account[0].split("/")[0]:
            msg = MessageDlgController(self.view.name_entry_focus)
            msg.show_message("You can't add yourself as a friend", title="NEW BUDDY")
            return
        alias = self.view.alias_entry.text.strip()
        if alias == "":
            self.is_service.add_buddy(self.view.name_entry.text,
                    None)
        else:
            self.is_service.add_buddy(self.view.name_entry.text,
                    alias)
        self.view.hide(True)

    def show(self):
        self.view.show()
